@@ -12,9 +12,8 @@ DJANGO_MODEL_TO_SLUMBER_MODEL = {}
 # Stores the slumber models for given model URLs
 MODEL_URL_TO_SLUMBER_MODEL = {}
 
-
-# Stores the operations used for a given model on the server
-SLUMBER_MODEL_OPERATIONS = {}
+# Store the URIs for special operations
+OPERATION_URIS = {}
 
 
 # Add a location where we can save per thread data
