@@ -53,8 +53,7 @@ def _use_fake(url):
     logging.debug("Using real HTTP for %s", url)
 
 
-def _calculate_signature(authn_name, method, url, body,
-        username, for_fake_client):
+def _calculate_signature(authn_name, method, url, body, username):
     """Do the signed request calculation.
     """
     # We need all arguments and all locals
@@ -84,11 +83,7 @@ def _calculate_signature(authn_name, method, url, body,
         headers[key] = value
     logging.debug("_calculate_signature %s adding headers: %s",
         method, headers)
-    if for_fake_client:
-        return dict([('HTTP_' + k.upper().replace('-', '_'), v)
-            for k, v in headers.items()])
-    else:
-        return headers
+    return headers
 
 
 def for_user(name):
@@ -111,7 +106,7 @@ def for_user(name):
     return decorator
 
 
-def _sign_request(method, url, body, for_fake_client):
+def _sign_request(method, url, body):
     """Calculate the request headers that need to be added so that the
     request is properly signed and the Slumber server will consider
     the current user to be authenticated.
@@ -122,29 +117,37 @@ def _sign_request(method, url, body, for_fake_client):
     if authn_name:
         name = getattr(PER_THREAD, 'username', None)
         return _calculate_signature(
-            authn_name, method, url, body, name, for_fake_client)
+            authn_name, method, url, body, name)
     else:
         return {}
 
 
-def get(url, ttl=0, codes=None):
+def _fake_http_headers(headers):
+    """Convert the headers into a form suitable for the Fake HTTP client.
+    """
+    return dict([('HTTP_' + k.upper().replace('-', '_'), v)
+            for k, v in headers.items()])
+
+
+def get(url, ttl=0, codes=None, headers=None):
     """Perform a GET request against a Slumber server.
     """
-    return _get(url, ttl, codes)
+    return _get(url, ttl, codes, headers)
 
 
-def _get(url, ttl, codes):
+def _get(url, ttl, codes, headers):
     """Mockable version of the user agent get.
     """
     # Pylint gets confused by the fake HTTP client
     # pylint: disable=E1103
-    url_fragment = _use_fake(url)
     codes = codes or [200]
+    headers = headers or dict(Accept='application/json')
+    url_fragment = _use_fake(url)
     if url_fragment:
         file_spec, query = _parse_qs(url_fragment)
-        headers = _sign_request('GET', file_spec, query, True)
+        headers.update(_sign_request('GET', file_spec, query))
         response = FakeClient().get(file_spec, query,
-            HTTP_HOST='localhost:8000', **headers)
+            HTTP_HOST='localhost:8000', **_fake_http_headers(headers))
         if response.status_code in [301, 302] and \
                 response.status_code not in codes:
             return get(response['location'], ttl, codes)
@@ -159,7 +162,7 @@ def _get(url, ttl, codes):
                 url, cache_key)
             _, _, path, _, query, _ = urlparse(url)
             for _ in range(0, 3):
-                headers = _sign_request('GET', path, query or '', False)
+                headers.update(_sign_request('GET', path, query or ''))
                 response, content = _real().request(
                     url, headers=headers)
                 if response.status in codes:
@@ -172,7 +175,10 @@ def _get(url, ttl, codes):
             logging.debug("Fetched %s from cache key %s", url, cache_key)
             response, content = cached
             response.from_cache = True
-    return response, loads(content)
+    try:
+        return response, loads(content)
+    except JSONDecodeError:
+        return response, {}
 
 
 def post(url, data, codes=None):
@@ -188,18 +194,20 @@ def _post(url, data, codes):
     # pylint: disable=E1101
     # Pylint gets confused by the fake HTTP client
     # pylint: disable=E1103
+    headers = dict(Accept='application/json')
     body = dumps(data) if data else ''
     url_fragment = _use_fake(url)
     if url_fragment:
+        headers.update(_sign_request('POST', url_fragment, body))
         response = FakeClient().post(url_fragment, body,
             content_type='application/json',
             HTTP_HOST='localhost:8000',
-            **_sign_request('POST', url_fragment, body, True))
+            **_fake_http_headers(headers))
         assert response.status_code in (codes or [200]), \
             (url_fragment, response, response.content)
         content = response.content
     else:
-        headers = _sign_request('POST', urlparse(url).path, body, False)
+        headers.update(_sign_request('POST', urlparse(url).path, body))
         headers['Content-Type'] = 'application/json'
         response, content = _real().request(url, "POST", body=body,
             headers = headers)
