@@ -1,15 +1,17 @@
 """
     Some basic server views.
 """
+import logging
+
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect, \
     HttpResponsePermanentRedirect, HttpResponseNotFound
 
+from slumber._caches import OPERATION_URIS
 from slumber.server import get_slumber_service, get_slumber_root, \
     get_slumber_services
 from slumber.server.http import view_handler
 from slumber.server.meta import applications
-from slumber.server.model import NotAnOperation
 
 
 @view_handler
@@ -19,10 +21,31 @@ def service_root(request, response):
     # We have many return statements, but there's no point in artificially
     # breaking the function up to reduce them
     # pylint: disable = R0911
+    # pylint: disable = too-many-branches
+    # pylint: disable = too-many-locals
+    service = get_slumber_service()
+    apps = applications()
+
     if not request.path.endswith('/'):
         return HttpResponsePermanentRedirect(request.path + '/')
     path = request.path[len(reverse('slumber.server.views.service_root')):-1]
-    service = get_slumber_service()
+
+    longest = None
+    for op_name in OPERATION_URIS.keys():
+        if not longest or len(op_name) > len(longest):
+            logging.debug("Comparing %s with %s", path, op_name)
+            if path.startswith(op_name):
+                longest = op_name
+    if longest:
+        operation = OPERATION_URIS[longest]
+        if len(path) > len(longest) + 1:
+            path_remainder = path[len(longest)+1:].split('/')
+        else:
+            path_remainder = []
+        logging.debug("%s %s %s", path, longest, path_remainder)
+        return operation.operation(request, response,
+            operation.model.app, operation.model, *path_remainder)
+
     if service:
         if not path:
             return get_service_directory(request, response)
@@ -31,16 +54,16 @@ def service_root(request, response):
         path = path[len(service) + 1:]
 
     if not path:
-        return get_applications(request, response)
+        return _get_applications(request, response, apps)
     else:
         # Find the app with the longest matching path
-        apps = [a for a in applications() if path.startswith(a.path)]
+        apps = [a for a in apps if path.startswith(a.path)]
         application = None
         for app in apps:
             if not application or len(app.path) > len(application.path):
                 application = app
         if not application:
-            return HttpResponseNotFound()
+            return HttpResponseNotFound("No app")
         remaining_path = path[len(application.path)+1:]
         if not remaining_path:
             return get_models(request, response, application)
@@ -54,11 +77,11 @@ def service_root(request, response):
         try:
             # Execute the operation (if it can be found)
             operation_name = models.pop(0)
-            operation = model.operation_by_name(operation_name)
+            operation = model.operations[operation_name]
             return operation.operation(request, response,
                 application.path, model.name, *models)
-        except NotAnOperation:
-            return HttpResponseNotFound()
+        except KeyError:
+            return HttpResponseNotFound("No op")
 
 
 def get_service_directory(_request, response):
@@ -67,7 +90,7 @@ def get_service_directory(_request, response):
     response['services'] = get_slumber_services()
 
 
-def get_applications(request, response):
+def _get_applications(request, response, apps):
     """Return the list of applications and the data connection URLs for them.
     """
     root = get_slumber_root()
@@ -78,9 +101,9 @@ def get_applications(request, response):
                 return HttpResponseRedirect(root + app.models[modelname].path)
         return HttpResponseNotFound()
     response['apps'] = dict([(app.name, root + app.path + '/')
-        for app in applications()])
+        for app in apps])
     response['configuration'] = dict([(app.name, app.configuration)
-        for app in applications() if getattr(app, 'configuration', None)])
+        for app in apps if getattr(app, 'configuration', None)])
     get_service_directory(request, response)
 
 
@@ -107,6 +130,6 @@ def get_model(_, response, model):
         list(model.model._meta.unique_together)
     response['data_arrays'] = model.data_arrays
     response['operations'] = dict(
-        [(op.name, root + op.path)
-            for op in model.operations() if op.model_operation])
+        [(op.name, op.uri or root + op.path)
+            for op in model.operations.values() if op.model_operation])
 
