@@ -2,7 +2,12 @@
 """
     The Django URLs for the server.
 """
-from django.conf.urls.defaults import patterns
+try:
+    # This API has changed.
+    # pylint: disable=no-name-in-module
+    from django.conf.urls import patterns
+except ImportError:
+    from django.conf.urls.defaults import patterns
 
 
 # The name urlpatterns is defined by Django and we can't change it
