@@ -4,7 +4,7 @@ from django.conf import settings
 from django.contrib.auth.models import User
 
 from slumber.connector import Client
-from slumber.connector.ua import _calculate_signature
+from slumber.connector.ua import _calculate_signature, _fake_http_headers
 
 
 class ConfigureUser(object):
@@ -26,12 +26,12 @@ class ConfigureUser(object):
         [p.stop() for p in self.__patchers]
 
     def signed_get(self,  username, url='/'):
-        headers = _calculate_signature('service', 'GET', url, '', username, True)
-        return self.client.get(url, **headers)
+        headers = _calculate_signature('service', 'GET', url, '', username)
+        return self.client.get(url, **_fake_http_headers(headers))
 
     def signed_post(self, username, url, data):
-        headers = _calculate_signature('service', 'POST', url, data, username, True)
-        return self.client.post(url, data, **headers)
+        headers = _calculate_signature('service', 'POST', url, data, username)
+        return self.client.post(url, data, **_fake_http_headers(headers))
 
 
 class ConfigureAuthnBackend(ConfigureUser):
